package com.jsowell.pile.service;

import com.jsowell.pile.domain.OrderAbnormalRecord;

import java.util.List;

/**
 * 订单异常记录Service接口
 *
 * @author jsowell
 * @date 2023-02-13
 */
public interface IOrderAbnormalRecordService {
	/**
	 * 查询订单异常记录
	 *
	 * @param id 订单异常记录主键
	 * @return 订单异常记录
	 */
	public OrderAbnormalRecord selectOrderAbnormalRecordById(Integer id);

	/**
	 * 查询订单异常记录列表
	 *
	 * @param orderAbnormalRecord 订单异常记录
	 * @return 订单异常记录集合
	 */
	public List<OrderAbnormalRecord> selectOrderAbnormalRecordList(OrderAbnormalRecord orderAbnormalRecord);

	/**
	 * 新增订单异常记录
	 *
	 * @param orderAbnormalRecord 订单异常记录
	 * @return 结果
	 */
	public int insertOrderAbnormalRecord(OrderAbnormalRecord orderAbnormalRecord);

	/**
	 * 修改订单异常记录
	 *
	 * @param orderAbnormalRecord 订单异常记录
	 * @return 结果
	 */
	public int updateOrderAbnormalRecord(OrderAbnormalRecord orderAbnormalRecord);

	/**
	 * 批量删除订单异常记录
	 *
	 * @param ids 需要删除的订单异常记录主键集合
	 * @return 结果
	 */
	public int deleteOrderAbnormalRecordByIds(Integer[] ids);

	/**
	 * 删除订单异常记录信息
	 *
	 * @param id 订单异常记录主键
	 * @return 结果
	 */
	public int deleteOrderAbnormalRecordById(Integer id);
}
